@@ -11,6 +11,7 @@ import textwrap
 from collections import OrderedDict
 from contextlib import suppress
 from datetime import timedelta
+from functools import lru_cache, partial
 
 from qt.core import (
     QAction,
@@ -52,6 +53,7 @@ from calibre import force_unicode
 from calibre.gui2 import config as gconf
 from calibre.gui2 import error_dialog, gprefs
 from calibre.gui2.search_box import SearchBox2
+from calibre.utils.config import JSONConfig
 from calibre.utils.date import utcnow
 from calibre.utils.localization import canonicalize_lang, get_lang
 from calibre.utils.network import internet_connected
@@ -59,6 +61,11 @@ from calibre.web.feeds.recipes.model import RecipeModel
 from polyglot.builtins import iteritems
 
 
+@lru_cache(2)
+def sprefs():
+    return JSONConfig('recipe-scheduler')
+
+
 def convert_day_time_schedule(val):
     day_of_week, hour, minute = val
     if day_of_week == -1:
@@ -193,7 +200,7 @@ class DaysOfMonth(Base):
                 x.strip()]
         try:
             days_of_month = tuple(map(int, parts))
-        except:
+        except Exception:
             days_of_month = (1,)
         if not days_of_month:
             days_of_month = (1,)
@@ -421,7 +428,7 @@ class SchedulerDialog(QDialog):
             self.recipe_model.searched.disconnect(self.search.search_done)
             self.search.search.disconnect()
             self.download.disconnect()
-        except:
+        except Exception:
             pass
         self.recipe_model = None
 
@@ -518,7 +525,7 @@ class SchedulerDialog(QDialog):
         recipe = self.recipe_model.recipe_from_urn(urn)
         try:
             schedule_info = self.recipe_model.schedule_info_from_urn(urn)
-        except:
+        except Exception:
             # Happens if user does something stupid like unchecking all the
             # days of the week
             schedule_info = None
@@ -640,6 +647,10 @@ class Scheduler(QObject):
                 QIcon.ic('download-metadata.png'),
                 _('Download all scheduled news sources'),
                 self.download_all_scheduled)
+        self.recent_menu = m = QMenu(_('Redownload...'))
+        m.addAction('dummy')
+        m.aboutToShow.connect(self.populate_recent_menu)
+        self.news_menu.addMenu(m)
 
         self.timer = QTimer(self)
         self.timer.start(int(self.INTERVAL * 60 * 1000))
@@ -647,6 +658,31 @@ class Scheduler(QObject):
         self.oldest = gconf['oldest_news']
         QTimer.singleShot(5 * 1000, self.oldest_check)
 
+    def populate_recent_menu(self):
+        m: QMenu = self.recent_menu
+        m.clear()
+        p = sprefs()
+        history = p.get('history', ())
+        if history:
+            for arg in reversed(history):
+                ac = QAction(arg['title'], m)
+                ac.setIcon(self.recipe_model.favicon_for_urn(arg['urn']))
+                m.addAction(ac)
+                ac.triggered.connect(partial(self.download, arg['urn']))
+            m.addSeparator()
+            ac = QAction(_('Clear this list'), m)
+            ac.setIcon(QIcon.ic('trash.png'))
+            m.addAction(ac)
+            ac.triggered.connect(self.clear_history)
+        else:
+            nrdnac = QAction(_('No recently downloaded news'), m)
+            m.addAction(nrdnac)
+
+    def clear_history(self):
+        p = sprefs()
+        with suppress(KeyError):
+            del p['history']
+
     @property
     def db(self):
         from calibre.gui2.ui import get_gui
@@ -666,7 +702,7 @@ class Scheduler(QObject):
             try:
                 ids = list(db.tags_older_than(_('News'),
                     delta, must_have_authors=['calibre']))
-            except:
+            except Exception:
                 # Happens if library is being switched
                 ids = []
             if ids:
@@ -719,6 +755,13 @@ class Scheduler(QObject):
 
     def recipe_downloaded(self, arg):
         self.lock.lock()
+        p = sprefs()
+        history = p.get('history', [])
+        history = [a for a in history if a['urn'] != arg['urn']]
+        history.append(arg)
+        if len(history) > (limit := 20):
+            history = history[len(history)-limit:]
+        p.set('history', history)
         try:
             self.recipe_model.update_last_downloaded(arg['urn'])
             self.download_queue.remove(arg['urn'])
